package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.ObjectStorageServicesMapper;
import com.zyc.system.domain.ObjectStorageServices;
import com.zyc.system.service.IObjectStorageServicesService;

/**
 * 对象存储服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class ObjectStorageServicesServiceImpl implements IObjectStorageServicesService 
{
    @Autowired
    private ObjectStorageServicesMapper objectStorageServicesMapper;

    /**
     * 查询对象存储服务
     * 
     * @param id 对象存储服务主键
     * @return 对象存储服务
     */
    @Override
    public ObjectStorageServices selectObjectStorageServicesById(Integer id)
    {
        return objectStorageServicesMapper.selectObjectStorageServicesById(id);
    }

    /**
     * 查询对象存储服务列表
     * 
     * @param objectStorageServices 对象存储服务
     * @return 对象存储服务
     */
    @Override
    public List<ObjectStorageServices> selectObjectStorageServicesList(ObjectStorageServices objectStorageServices)
    {
        return objectStorageServicesMapper.selectObjectStorageServicesList(objectStorageServices);
    }

    /**
     * 新增对象存储服务
     * 
     * @param objectStorageServices 对象存储服务
     * @return 结果
     */
    @Override
    public int insertObjectStorageServices(ObjectStorageServices objectStorageServices)
    {
        return objectStorageServicesMapper.insertObjectStorageServices(objectStorageServices);
    }

    /**
     * 修改对象存储服务
     * 
     * @param objectStorageServices 对象存储服务
     * @return 结果
     */
    @Override
    public int updateObjectStorageServices(ObjectStorageServices objectStorageServices)
    {
        return objectStorageServicesMapper.updateObjectStorageServices(objectStorageServices);
    }

    /**
     * 批量删除对象存储服务
     * 
     * @param ids 需要删除的对象存储服务主键
     * @return 结果
     */
    @Override
    public int deleteObjectStorageServicesByIds(Integer[] ids)
    {
        return objectStorageServicesMapper.deleteObjectStorageServicesByIds(ids);
    }

    /**
     * 删除对象存储服务信息
     * 
     * @param id 对象存储服务主键
     * @return 结果
     */
    @Override
    public int deleteObjectStorageServicesById(Integer id)
    {
        return objectStorageServicesMapper.deleteObjectStorageServicesById(id);
    }
}
